@@ -210,6 +210,8 @@ class _CachedFunction(object):
             data = self._compute_hash(key.__dict__)
         elif isinstance(key, (bool, int, long, float,)):
             data = str(self._pickler(key))
+        elif key is None:
+            data = "__None__"
         else:
             raise Exception("can not compute hash for %r" % (key,))
         if not isinstance(data, basestring):
